<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" 
    xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
    xmlns:dc="http://purl.org/dc/elements/1.1/"
    xmlns:dcterms="http://purl.org/dc/terms/"
    xmlns:rdf="http://www.w3.org/1999/02/22-rdf-syntax-ns#"
	xmlns:owl="http://www.w3.org/2002/07/owl#"
    xmlns:skos="http://www.w3.org/2004/02/skos/core#">
<!-- Developed by Christophe Dupriez for the ASKOSI project
     http://www.askosi.org
     Please feel free to modify but please keep this reference -->	 
	<xsl:output method="xml" version="1.0" omit-xml-declaration="no" indent="no" encoding="utf-8"/>
    
        <xsl:template match="text()">
                <!--
                                Do nothing.

                                Override, effectively, the "Built-In" rule which will
                                process all text inside elements otherwise not matched by any xsl:template.

                                Note: With this in place, be sure to then provide templates or "value-of"
                                statements to actually _get_ the (desired) text out to the result document!
                -->
        </xsl:template>

    <xsl:template match="/rdf:RDF/skos:ConceptScheme | /rdf:RDF/rdf:Description[rdf:type/@rdf:resource = 'http://www.w3.org/2004/02/skos/core#ConceptScheme'] | /rdf:RDF/owl:Thing[rdf:type/@rdf:resource = 'http://www.w3.org/2004/02/skos/core#ConceptScheme']">
		 <xsl:element name="conceptScheme"><xsl:attribute name="about"><xsl:value-of select="@rdf:about"/></xsl:attribute>
                <xsl:for-each select="./dc:title | ./dcterms:title ">
                    <xsl:element name="title"><xsl:attribute name="lang"><xsl:value-of select="@xml:lang"/></xsl:attribute><xsl:value-of select="."/></xsl:element>
                </xsl:for-each>
				<!--xsl:element name="namespace"><xsl:value-of select="@rdf:about"/></xsl:element-->
                <xsl:call-template name="termList" />
		</xsl:element>
    </xsl:template>

    <xsl:template name="termList">
        <xsl:for-each select="./skos:Concept | /rdf:RDF/skos:Concept | ./rdf:Description[rdf:type/@rdf:resource = 'http://www.w3.org/2004/02/skos/core#Concept'] | /rdf:RDF/rdf:Description[rdf:type/@rdf:resource = 'http://www.w3.org/2004/02/skos/core#Concept'] | ./owl:Thing[rdf:type/@rdf:resource = 'http://www.w3.org/2004/02/skos/core#Concept'] | /rdf:RDF/owl:Thing[rdf:type/@rdf:resource = 'http://www.w3.org/2004/02/skos/core#Concept']">
		          <xsl:call-template name="oneConcept" />
        </xsl:for-each>
    </xsl:template>

    <xsl:template name="oneConcept">
			<xsl:variable name="about"><xsl:choose>
				<xsl:when test="contains(@rdf:about,'#')"><xsl:value-of select="substring-after(@rdf:about,'#')"/></xsl:when>
				<xsl:when test="contains(@rdf:about,'_')"><xsl:value-of select="substring-after(@rdf:about,'_')"/></xsl:when>
				<xsl:when test="contains(@rdf:about,'=')"><xsl:value-of select="substring-after(@rdf:about,'=')"/></xsl:when>
				<xsl:when test="contains(@rdf:about,'?')"><xsl:value-of select="substring-after(@rdf:about,'?')"/></xsl:when>
				<xsl:when test="contains(@rdf:about,'/')"><xsl:value-of select="substring-after(@rdf:about,'/')"/></xsl:when>
				<xsl:otherwise><xsl:value-of select="@rdf:about"/></xsl:otherwise>
				</xsl:choose></xsl:variable>
            <xsl:element name="concept">
					<xsl:attribute name="about"><xsl:value-of select="$about"/></xsl:attribute>
                    <xsl:for-each select="./skos:prefLabel">
						<xsl:element name="prefLabel"><xsl:attribute name="lang"><xsl:value-of select="@xml:lang"/></xsl:attribute><xsl:value-of select="."/></xsl:element>
                    </xsl:for-each>
                    <xsl:for-each select="./skos:altLabel">
						<xsl:element name="altLabel"><xsl:attribute name="lang"><xsl:value-of select="@xml:lang"/></xsl:attribute><xsl:value-of select="."/></xsl:element>
                    </xsl:for-each>
                    <xsl:for-each select="./skos:hiddenLabel">
						<xsl:element name="hiddenLabel"><xsl:attribute name="lang"><xsl:value-of select="@xml:lang"/></xsl:attribute><xsl:value-of select="."/></xsl:element>
                   </xsl:for-each>
                    <xsl:for-each select="./skos:changeNote">
						<xsl:element name="changeNote"><xsl:attribute name="lang"><xsl:value-of select="@xml:lang"/></xsl:attribute><xsl:value-of select="."/></xsl:element>
                    </xsl:for-each>
                    <xsl:for-each select="./skos:definition">
						<xsl:element name="definition"><xsl:attribute name="lang"><xsl:value-of select="@xml:lang"/></xsl:attribute><xsl:value-of select="."/></xsl:element>
                    </xsl:for-each>
                    <xsl:for-each select="./skos:editorialNote">
						<xsl:element name="editorialNote"><xsl:attribute name="lang"><xsl:value-of select="@xml:lang"/></xsl:attribute><xsl:value-of select="."/></xsl:element>
                    </xsl:for-each>
                    <xsl:for-each select="./skos:example">
						<xsl:element name="example"><xsl:attribute name="lang"><xsl:value-of select="@xml:lang"/></xsl:attribute><xsl:value-of select="."/></xsl:element>
                    </xsl:for-each>
                    <xsl:for-each select="./skos:historyNote">
						<xsl:element name="historyNote"><xsl:attribute name="lang"><xsl:value-of select="@xml:lang"/></xsl:attribute><xsl:value-of select="."/></xsl:element>
                    </xsl:for-each>
                    <xsl:for-each select="./skos:scopeNote">
						<xsl:element name="scopeNote"><xsl:attribute name="lang"><xsl:value-of select="@xml:lang"/></xsl:attribute><xsl:value-of select="."/></xsl:element>
                    </xsl:for-each>
                    <xsl:for-each select="./skos:exactMatch">
						<xsl:element name="exactMatch"><xsl:call-template name="getExternalProperty"/></xsl:element>
                    </xsl:for-each>
                    <xsl:for-each select="./skos:closeMatch">
						<xsl:element name="closeMatch"><xsl:call-template name="getExternalProperty"/></xsl:element>
                    </xsl:for-each>
                    <xsl:for-each select="./skos:broader">
						<xsl:element name="broader"><xsl:call-template name="getProperty"/></xsl:element>
                    </xsl:for-each>
                    <xsl:for-each select="./skos:narrower">
						<xsl:element name="narrower"><xsl:call-template name="getProperty"/></xsl:element>
                    </xsl:for-each>
                    <xsl:for-each select="./skos:related">
						<xsl:element name="related"><xsl:call-template name="getProperty"/></xsl:element>
                   </xsl:for-each>
                    <xsl:for-each select="./skos:broadMatch">
						<xsl:element name="broadMatch"><xsl:call-template name="getExternalProperty"/></xsl:element>
                    </xsl:for-each>
                    <xsl:for-each select="./skos:narrowMatch">
						<xsl:element name="narrowMatch"><xsl:call-template name="getExternalProperty"/></xsl:element>
                    </xsl:for-each>
                    <xsl:for-each select="./skos:relatedMatch">
						<xsl:element name="relatedMatch"><xsl:call-template name="getExternalProperty"/></xsl:element>
                    </xsl:for-each>
                </xsl:element>
    </xsl:template>
	<xsl:template name="getProperty">
			<xsl:choose>
				<xsl:when test="contains(@rdf:resource,'#')"><xsl:value-of select="substring-after(@rdf:resource,'#')"/></xsl:when>
				<xsl:when test="contains(@rdf:resource,'_')"><xsl:value-of select="substring-after(@rdf:resource,'_')"/></xsl:when>
				<xsl:when test="contains(@rdf:resource,'=')"><xsl:value-of select="substring-after(@rdf:resource,'=')"/></xsl:when>
				<xsl:when test="contains(@rdf:resource,'?')"><xsl:value-of select="substring-after(@rdf:resource,'?')"/></xsl:when>
				<xsl:when test="contains(@rdf:resource,'/')"><xsl:value-of select="substring-after(@rdf:resource,'/')"/></xsl:when>
				<xsl:otherwise><xsl:value-of select="@rdf:resource"/></xsl:otherwise>
			</xsl:choose>
	</xsl:template>
	<xsl:template name="getExternalProperty">
			<xsl:choose>
				<xsl:when test="contains(@rdf:resource,'#')"><xsl:value-of select="substring-after(@rdf:resource,'#')"/></xsl:when>
				<xsl:when test="contains(@rdf:resource,'=')"><xsl:value-of select="substring-after(@rdf:resource,'=')"/></xsl:when>
				<xsl:when test="contains(@rdf:resource,'?')"><xsl:value-of select="substring-after(@rdf:resource,'?')"/></xsl:when>
				<xsl:when test="contains(@rdf:resource,'/')"><xsl:value-of select="substring-after(@rdf:resource,'/')"/></xsl:when>
				<xsl:otherwise><xsl:value-of select="@rdf:resource"/></xsl:otherwise>
			</xsl:choose>
	</xsl:template>
</xsl:stylesheet>
